<?php

namespace Litecms\Zingapp\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Zingapp\Events\CuisineWorkflow as CuisineWorkflowEvent;
use Litecms\Zingapp\Notifications\CuisineWorkflow as CuisineWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class CuisineWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(CuisineWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $cuisine is submitted.
     *
     * @param CuisineWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(CuisineWorkflowEvent $event)
    {
        $client = $event->$cuisine->client;
        Notification::send($client, new CuisineWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $cuisine is published.
     *
     * @param CuisineWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(CuisineWorkflowEvent $event)
    {
        $client = $event->$cuisine->client;
        Notification::send($client, new CuisineWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $cuisine is approved.
     *
     * @param CuisineWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(CuisineWorkflowEvent $event)
    {
        $client = $event->$cuisine->client;
        Notification::send($client, new CuisineWorkflowNotification($event));
    }

    /**
     * Handles the $cuisine workflow event as a listener.
     *
     * @param CuisineWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(CuisineWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
