<?php

namespace Litecms\Zingapp\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Zingapp\Models\Cuisine;

class CuisinePolicy
{


    /**
     * Determine if the given user can view the cuisine.
     *
     * @param UserPolicyInterface $authUser
     * @param Cuisine $cuisine
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Cuisine $cuisine)
    {
        if ($authUser->canDo('zingapp.cuisine.view') && $authUser->isAdmin()) {
            return true;
        }

        return $cuisine->user_id == user_id() && $cuisine->user_type == user_type();
    }

    /**
     * Determine if the given user can create a cuisine.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('zingapp.cuisine.create');
    }

    /**
     * Determine if the given user can update the given cuisine.
     *
     * @param UserPolicyInterface $authUser
     * @param Cuisine $cuisine
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Cuisine $cuisine)
    {
        if ($authUser->canDo('zingapp.cuisine.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $cuisine->user_id == user_id() && $cuisine->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given cuisine.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Cuisine $cuisine)
    {
        return $cuisine->user_id == user_id() && $cuisine->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given cuisine.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Cuisine $cuisine)
    {
        if ($authUser->canDo('zingapp.cuisine.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given cuisine.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Cuisine $cuisine)
    {
        if ($authUser->canDo('zingapp.cuisine.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
